@@ -1,21 +1,21 @@
 import asyncio
+from beniutils.http import getHeaderByDefault
 import binascii
 import hashlib
 import os
 
 import aiofiles
 import aiohttp
-import xlrd3
 
-from . import _getHeaderByDefault, makeFolder
+from . import makeFolder
 from .log import warning
 
-_maxAsyncFileNum = 5000
-_currentAsyncFileNum = 0
-_waitAsyncFileTime = 0.5
+_maxAsyncFileNum: int = 5000
+_currentAsyncFileNum: int = 0
+_waitAsyncFileTime: float = 0.5
 
 
-def setAsyncFileMaxNum(value):
+def setAsyncFileMaxNum(value: int):
     global _maxAsyncFileNum
     _maxAsyncFileNum = value
 
@@ -27,20 +27,20 @@ async def asyncAwait(*taskList):
     return resultList
 
 
-async def asyncWriteFile(file, data, encoding='utf8', newline='\n'):
+async def asyncWriteFile(file: str, content: str, encoding: str = 'utf8', newline: str = '\n'):
     makeFolder(os.path.dirname(file))
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
         await asyncio.sleep(_waitAsyncFileTime)
     _currentAsyncFileNum += 1
     async with aiofiles.open(file, 'w', encoding=encoding, newline=newline) as f:
-        await f.write(data)
+        await f.write(content)
         await f.flush()
         await f.close()
     _currentAsyncFileNum -= 1
 
 
-async def asyncWriteBinFile(file, data):
+async def asyncWriteBinFile(file: str, data: bytes):
     makeFolder(os.path.dirname(file))
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
@@ -53,7 +53,7 @@ async def asyncWriteBinFile(file, data):
     _currentAsyncFileNum -= 1
 
 
-async def asyncReadFile(file, encoding='utf8', newline='\n'):
+async def asyncReadFile(file: str, encoding: str = 'utf8', newline: str = '\n'):
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
         await asyncio.sleep(_waitAsyncFileTime)
@@ -65,7 +65,7 @@ async def asyncReadFile(file, encoding='utf8', newline='\n'):
     return data
 
 
-async def asyncReadBinFile(file):
+async def asyncReadBinFile(file: str):
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
         await asyncio.sleep(_waitAsyncFileTime)
@@ -77,12 +77,6 @@ async def asyncReadBinFile(file):
     return data
 
 
-async def asyncOpenXlsx(file):
-    data = await asyncReadBinFile(file)
-    return xlrd3.open_workbook(file_contents=data, formatting_info=True)
-    # 只提供了异步打开xlsx的方法，没有提供异步写入xlsx的方法，因为xlwt不支持
-
-
 async def asyncGetFileMD5(file: str):
     data = await asyncReadBinFile(file)
     return hashlib.md5(data).hexdigest()
@@ -93,7 +87,7 @@ async def asyncGetFileCRC32(file: str):
     return binascii.crc32(data)
 
 
-async def asyncGetFileCRCHex(file):
+async def asyncGetFileCRCHex(file: str):
     return hex(await asyncGetFileCRC32(file))[2:].zfill(8)
 
 
@@ -113,21 +107,21 @@ async def asyncExecute(*parList: str):
     return proc.returncode, stdout, stderr
 
 
-_maxAsyncHttpNum = 3
-_currentAsyncHttpNum = 0
-_waitAsyncHttpTime = 0.1
+_maxAsyncHttpNum: int = 3
+_currentAsyncHttpNum: int = 0
+_waitAsyncHttpTime: float = 0.1
 
 
-def setAsyncHttpMaxNum(value):
+def setAsyncHttpMaxNum(value: int):
     global _maxAsyncHttpNum
     _maxAsyncHttpNum = value
 
 
-async def asyncHttpGet(url, headers=None, timeout=30, retry=3):
+async def asyncHttpGet(url: str, headers=None, timeout: int = 30, retry: int = 3):
     initAioHttp()
     global _currentAsyncHttpNum
-    headers = _getHeaderByDefault(headers)
-    result = None
+    headers = getHeaderByDefault(headers)
+    result: bytes = b""
     response = None
     currentTry = 0
     while _currentAsyncHttpNum >= _maxAsyncHttpNum:
@@ -157,7 +151,7 @@ async def asyncHttpGet(url, headers=None, timeout=30, retry=3):
     return result, response
 
 
-async def asyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
+async def asyncHttpPost(url: str, data=None, headers=None, timeout: int = 30, retry: int = 3):
     initAioHttp()
     global _currentAsyncHttpNum
     headers = _getHeaderByDefault(headers)
@@ -192,8 +186,8 @@ async def asyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
     return result, response
 
 
-async def asyncDownload(url, file):
-    result, _response = await asyncHttpGet(url)
+async def asyncDownload(url: str, file: str):
+    result, _ = await asyncHttpGet(url)
     await asyncWriteBinFile(file, result)
 
 
