@@ -13,10 +13,12 @@ from .print import (BACKGROUND_DARKGREEN, BACKGROUND_DARKPINK,
                     FOREGROUND_BLACK, FOREGROUND_DARKRED, FOREGROUND_WHITE,
                     resetPrintColor, setPrintColor)
 
+TaskDataType = tuple[str, dict[str, Any]]
+
 _workspacePath: str = ""
 
 
-def initTask(exeWorkspace: str, devWorkspace: str, devTaskList: list[list[Any]]):
+def initTask(exeWorkspace: str, devWorkspace: str, devTaskList: list[TaskDataType]):
     global _workspacePath
     if _isDev():
         _workspacePath = getPath(devWorkspace)
@@ -65,7 +67,7 @@ def _setPrintRedColor():
 
 def _runTaskFile(file: str):
     isException = False
-    taskList: list[list[Any]] = []
+    taskList: list[TaskDataType] = []
     try:
         fileContent = readFile(file)
         findStr = ":: ---------------------------------------- ::"
@@ -76,14 +78,14 @@ def _runTaskFile(file: str):
         lineAry = [x[2:].strip() for x in lineAry]
         for line in lineAry:
             sepIndex = line.find(" ")
+            parDict: dict[str, Any] = {}
             if sepIndex > -1:
                 moduleName = line[:sepIndex].strip()
                 parDict = eval(line[sepIndex:])
                 assert type(parDict) == dict, f"参数无法解析成字典类型 line={line}"
             else:
                 moduleName = line
-                parDict = {}
-            taskList.append([moduleName, parDict])
+            taskList.append((moduleName, parDict))
         assert len(taskList) > 0
         os.system(f"title={getFileBaseName(file)}")
     except:
@@ -99,7 +101,7 @@ def _runTaskFile(file: str):
 
 
 # [[moduleName, parDict], ...]
-def _runTaskList(taskList: list[list[Any]]):
+def _runTaskList(taskList: list[TaskDataType]):
     startTime = datetime.datetime.now()
     lockFile = None
     try:
@@ -110,8 +112,7 @@ def _runTaskList(taskList: list[list[Any]]):
             remove(logFile)
         logFile = getPath(logFolder, f"{time.strftime('%Y%m%d_%H%M%S')}.log")
         initLogger(logFile=logFile)
-        for moduleName, *parList in taskList:
-            parDict: Any = parList and parList[0] or {}
+        for moduleName, parDict in taskList:
             runTask(moduleName, **parDict)
     except Exception:
         import traceback
